@@ -36,6 +36,7 @@ module.exports = defineConfig({
     setupNodeEvents(on, config) {
       return require('./cypress/plugins/index.js')(on, config);
     },
-    baseUrl: 'http://localhost:5004'
+    baseUrl: 'http://localhost:5004',
+    supportFile: 'cypress/support/e2e.js'
   }
 });
