@@ -336,13 +336,14 @@ def search_origin(
 
 
 def search_origin_metadata(
-    fulltext: str, limit: int = 50
+    fulltext: str, limit: int = 50, return_metadata: bool = True
 ) -> Iterable[OriginMetadataInfo]:
     """Search for origins whose metadata match a provided string pattern.
 
     Args:
         fulltext: the string pattern to search for in origin metadata
         limit: the maximum number of found origins to return
+        return_metadata: if false, will only return the origin URL
 
     Returns:
         Iterable of origin metadata information for existing origins
@@ -357,24 +358,48 @@ def search_origin_metadata(
             metadata_pattern=fulltext,
             limit=limit,
         )
-        matches = idx_storage.origin_intrinsic_metadata_get(
-            [r["url"] for r in page_result.results]
-        )
+        origin_urls = [r["url"] for r in page_result.results]
+
+        if return_metadata:
+            metadata = {
+                r.id: r for r in idx_storage.origin_intrinsic_metadata_get(origin_urls)
+            }
+        else:
+            # Skip query to swh-indexer if we are not interested in the results
+            metadata = {}
+
+        # Results from swh-search are not guaranteed to be in
+        # idx_storage.origin_intrinsic_metadata (typically when they come from
+        # extrinsic metadata; or when the swh-indexer cache is cleared).
+        # When they are missing, we only return the origin url.
+        matches = [
+            metadata[url].to_dict() if url in metadata else {"id": url}
+            for url in origin_urls
+        ]
     else:
-        matches = idx_storage.origin_intrinsic_metadata_search_fulltext(
-            conjunction=[fulltext], limit=limit
-        )
+        matches = [
+            match.to_dict()
+            for match in idx_storage.origin_intrinsic_metadata_search_fulltext(
+                conjunction=[fulltext], limit=limit
+            )
+        ]
 
-    matches = [match.to_dict() for match in matches]
     origins = storage.origin_get([match["id"] for match in matches])
+
     for origin, match in zip(origins, matches):
         if not origin:
+            # filter out origins not present in the storage, as we do not have any
+            # meaningful content to display for that origin at the moment.
+            # This may occur when the storage database we use is lagging behind
+            # swh-search
             continue
         for field in ("from_directory", "from_revision"):
             # from_directory when using swh.indexer >= 2.0.0, from_revision otherwise
             if field in match:
                 match[field] = hashutil.hash_to_hex(match[field])
         del match["id"]
+        if not return_metadata:
+            match.pop("metadata", None)
         results.append(OriginMetadataInfo(url=origin.url, metadata=match))
 
     return results
@@ -1097,6 +1122,12 @@ def lookup_snapshot_sizes(
     # when null branches are present in the snapshot
     branch_counts.pop(None, None)
     snapshot_sizes.update(branch_counts)
+
+    snapshot_sizes["branch"] = sum(
+        snapshot_sizes.get(target_type, 0)
+        for target_type in ("content", "directory", "revision")
+    )
+
     return snapshot_sizes
 
 
